@@ -56,15 +56,12 @@ from numpy import arange, issubdtype, array, column_stack, shape
 from .figure import Figure
 from .scales import Scale, LinearScale, Mercator
 from .axes import Axis
-from .marks import (
-        Lines, Scatter, Hist, Bars, OHLC, Pie, Map, Image,
-        Label, HeatMap, GridHeatMap, topo_load, Boxplot
-    )
+from .marks import (Lines, Scatter, Hist, Bars, OHLC, Pie, Map, Image,
+                    Label, HeatMap, GridHeatMap, topo_load, Boxplot, Bins)
 from .toolbar import Toolbar
-from .interacts import (
-        BrushIntervalSelector, FastIntervalSelector, BrushSelector,
-        IndexSelector, MultiSelector, LassoSelector
-    )
+from .interacts import (BrushIntervalSelector, FastIntervalSelector,
+                        BrushSelector, IndexSelector, MultiSelector,
+                        LassoSelector)
 from traitlets.utils.sentinel import Sentinel
 import functools
 
@@ -77,9 +74,9 @@ Keep = Sentinel('Keep', 'bqplot.pyplot', '''
 # `scales`: The current set of scales which will be used for drawing a mark. if
 # the scale for an attribute is not present, it is created based on the range
 # type.
-# `scale_registry`: This is a dictionary where the keys are the context names and
-# the values are the set of scales which were used on the last plot in that
-# context. This is useful when switching context.
+# `scale_registry`: This is a dictionary where the keys are the context
+# names and the values are the set of scales which were used on the last plot
+# in that context. This is useful when switching context.
 # `last_mark`: refers to the last mark that has been plotted.
 # `current_key`: The key for the current context figure. If there is no key,
 # then the value is `None`.
@@ -253,8 +250,8 @@ def _process_data(*kwarg_names):
                    kw: data[kwargs[kw]] if hashable(data, kwargs[kw]) else kwargs[kw] for kw in set(kwarg_names).intersection(list(kwargs.keys()))
                 }
                 try:
-                    # if any of the plots want to use the index_data, they can use it by referring to
-                    # this attribute.
+                    # if any of the plots want to use the index_data, they can
+                    # use it by referring to this attribute.
                     data_kwargs['index_data'] = data.index
                 except AttributeError as e:
                     pass
@@ -543,14 +540,41 @@ def vline(level, **kwargs):
         y = [0, 1]
     else:
         x = column_stack([level, level])
-        y = [[0, 1]] * len(level)  # TODO: repeating [0, 1] should not be
-                                   # required once we allow for 2-D x and 1-D y
+        # TODO: repeating [0, 1] should not be required once we allow for
+        # 2-D x and 1-D y
+        y = [[0, 1]] * len(level)
     return plot(x, y, scales=scales, preserve_domain={
         'x': kwargs.get('preserve_domain', False),
         'y': True
     }, axes=False, update_context=False, **kwargs)
 
 
+def _process_cmap(cmap):
+    '''
+    Returns a kwarg dict suitable for a ColorScale
+    '''
+    option = {}
+    if isinstance(cmap, str):
+        option['scheme'] = cmap
+    elif isinstance(cmap, list):
+        option['colors'] = cmap
+    else:
+        raise ValueError('''`cmap` must be a string (name of a color scheme)
+                         or a list of colors, but a value of {} was given
+                         '''.format(cmap))
+    return option
+
+
+def set_cmap(cmap):
+    '''
+    Set the color map of the current 'color' scale.
+    '''
+    scale = _context['scales']['color']
+    for k, v in _process_cmap(cmap).items():
+        setattr(scale, k, v)
+    return scale
+
+
 def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
     """Draw the mark of specified mark type.
 
@@ -569,11 +593,20 @@ def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
     figure: Figure or None
         The figure to which the mark is to be added.
         If the value is None, the current figure is used.
+    cmap: list or string
+        List of css colors, or name of bqplot color scheme
     """
     fig = kwargs.pop('figure', current_figure())
     scales = kwargs.pop('scales', {})
     update_context = kwargs.pop('update_context', True)
 
+    # Set the color map of the color scale
+    cmap = kwargs.pop('cmap', None)
+    if cmap is not None:
+        # Add the colors or scheme to the color scale options
+        options['color'] = dict(options.get('color', {}),
+                                **_process_cmap(cmap))
+
     # Going through the list of data attributes
     for name in mark_type.class_trait_names(scaled=True):
         dimension = _get_attribute_dimension(name, mark_type)
@@ -602,7 +635,8 @@ def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
                     if Scale.scale_types[key].rtype == rtype and
                     issubdtype(dtype, Scale.scale_types[key].dtype)
                 ]
-            sorted_scales = sorted(compat_scale_types, key=lambda x: x.precedence)
+            sorted_scales = sorted(compat_scale_types,
+                                   key=lambda x: x.precedence)
             scales[name] = sorted_scales[-1](**options.get(name, {}))
             # Adding the scale to the context scales
             if update_context:
@@ -617,6 +651,7 @@ def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
         axes(mark, options=axes_options)
     return mark
 
+
 def _infer_x_for_line(y):
     """
     Infers the x for a line if no x is provided.
@@ -669,7 +704,7 @@ def plot(*args, **kwargs):
         if kwargs.get('index_data', None) is not None:
             kwargs['x'] = kwargs['index_data']
         else:
-            kwargs['x'] = _infer_x_for_line(args[0]);
+            kwargs['x'] = _infer_x_for_line(args[0])
     elif len(args) == 2:
         if type(args[1]) == str:
             kwargs['y'] = args[0]
@@ -709,15 +744,15 @@ def imshow(image, format, **kwargs):
     """Draw an image in the current context figure.
     Parameters
     ----------
-    image: image data 
+    image: image data
         Image data, depending on the passed format, can be one of:
             - an instance of an ipywidgets Image
             - a file name
             - a raw byte string
     format: {'widget', 'filename', ...}
         Type of the input argument.
-        If not 'widget' or 'filename', must be a format supported by the 
-        ipywidgets Image.
+        If not 'widget' or 'filename', must be a format supported by
+        the ipywidgets Image.
     options: dict (default: {})
         Options for the scales to be created. If a scale labeled 'x' is
         required for that mark, options['x'] contains optional keyword
@@ -832,6 +867,36 @@ def hist(sample, options={}, **kwargs):
     return _draw_mark(Hist, options=options, **kwargs)
 
 
+@_process_data()
+def bin(sample, options={}, **kwargs):
+    """Draw a histogram in the current context figure.
+    Parameters
+    ----------
+    sample: numpy.ndarray, 1d
+        The sample for which the histogram must be generated.
+    options: dict (default: {})
+        Options for the scales to be created. If a scale labeled 'x'
+        is required for that mark, options['x'] contains optional keyword
+        arguments for the constructor of the corresponding scale type.
+    axes_options: dict (default: {})
+        Options for the axes to be created. If an axis labeled 'x' is
+        required for that mark, axes_options['x'] contains optional
+        keyword arguments for the constructor of the corresponding axis type.
+    """
+    kwargs['sample'] = sample
+    scales = kwargs.pop('scales', {})
+    for xy in ['x', 'y']:
+        if xy not in scales:
+            dimension = _get_attribute_dimension(xy, Bars)
+            if dimension in _context['scales']:
+                scales[xy] = _context['scales'][dimension]
+            else:
+                scales[xy] = LinearScale(**options.get(xy, {}))
+                _context['scales'][dimension] = scales[xy]
+    kwargs['scales'] = scales
+    return _draw_mark(Bins, options=options, **kwargs)
+
+
 @_process_data('color')
 def bar(x, y, **kwargs):
     """Draws a bar chart in the current context figure.
@@ -856,6 +921,7 @@ def bar(x, y, **kwargs):
     kwargs['y'] = y
     return _draw_mark(Bars, **kwargs)
 
+
 @_process_data()
 def boxplot(x, y, **kwargs):
     """Draws a boxplot in the current context figure.
@@ -1021,9 +1087,9 @@ def _add_interaction(int_type, **kwargs):
 
     If a figure is passed using the key-word argument `figure` it is used. Else
     the context figure is used.
-    If a list of marks are passed using the key-word argument `marks` it is used.
-    Else the latest mark that is passed is used as the only mark associated with
-    the selector.
+    If a list of marks are passed using the key-word argument `marks` it
+    is used. Else the latest mark that is passed is used as the only mark
+    associated with the selector.
 
     Parameters
     ----------
@@ -1107,7 +1173,8 @@ def brush_int_selector(func=None, trait='selected', **kwargs):
 def int_selector(func=None, trait='selected', **kwargs):
     """Creates a `FastIntervalSelector` interaction for the `figure`.
 
-    Also attaches the function `func` as an event listener for the trait `trait`.
+    Also attaches the function `func` as an event listener for the
+    trait `trait`.
 
     Parameters
     ----------
@@ -1125,7 +1192,8 @@ def int_selector(func=None, trait='selected', **kwargs):
 def index_selector(func=None, trait='selected', **kwargs):
     """Creates an `IndexSelector` interaction for the `figure`.
 
-    Also attaches the function `func` as an event listener for the trait `trait`.
+    Also attaches the function `func` as an event listener for the
+    trait `trait`.
 
     Parameters
     ----------
@@ -1143,7 +1211,8 @@ def index_selector(func=None, trait='selected', **kwargs):
 def brush_selector(func=None, trait='selected', **kwargs):
     """Creates a `BrushSelector` interaction for the `figure`.
 
-    Also attaches the function `func` as an event listener for the trait `trait`.
+    Also attaches the function `func` as an event listener for the
+    trait `trait`.
 
     Parameters
     ----------
@@ -1161,7 +1230,8 @@ def brush_selector(func=None, trait='selected', **kwargs):
 def multi_selector(func=None, trait='selected', **kwargs):
     """Creates a `MultiSelector` interaction for the `figure`.
 
-    Also attaches the function `func` as an event listener for the trait `trait`.
+    Also attaches the function `func` as an event listener for the
+    trait `trait`.
 
     Parameters
     ----------
@@ -1179,7 +1249,8 @@ def multi_selector(func=None, trait='selected', **kwargs):
 def lasso_selector(func=None, trait='selected', **kwargs):
     """Creates a `LassoSelector` interaction for the `figure`.
 
-    Also attaches the function `func` as an event listener for the specified trait.
+    Also attaches the function `func` as an event listener for the
+    specified trait.
 
     Parameters
     ----------
@@ -1217,7 +1288,8 @@ def current_figure():
 
 
 def get_context():
-    """Used for debug only. Return a copy of the current global context dictionary."""
+    """Used for debug only. Return a copy of the current global
+    context dictionary."""
     return {k: v for k, v in _context.items()}
 
 
@@ -1260,7 +1332,8 @@ def _get_attribute_dimension(trait_name, mark_type=None):
     """
     if(mark_type is None):
         return trait_name
-    scale_metadata = mark_type.class_traits()['scales_metadata'].default_args[0]
+    scale_metadata = mark_type.class_traits()['scales_metadata']\
+        .default_args[0]
     return scale_metadata.get(trait_name, {}).get('dimension', None)
 
 
